@@ -2,26 +2,28 @@
 import sys
 import os
 import clr
+import time
 
 
-
-dll_path=os.path.split(os.path.realpath(__file__))[0]
+dll_path = os.path.split(os.path.realpath(__file__))[0]
 
 sys.path.append(str(dll_path))
 
 
 # install pythonnet
-try :
-   aiqi_blue=clr.AddReference('AIQI_Bluetooth_LIB')
+try:
+    aiqi_blue = clr.AddReference('AIQI_Bluetooth_LIB')
 except:
 
     print("please add AIQI_Bluetooth_LIB.ddl file ")
     sys.exit()
 
 
-from AIQI_Bluetooth import  *
+_aiqi_watcher = None
+_aiqi_gatt = None
 
 from enum import Enum
+from AIQI_Bluetooth import *
 
 class Connect_result(Enum):
     Connect_Notify_OK = 0
@@ -35,16 +37,51 @@ class Connect_result(Enum):
     Connect_Get_Char_fault = 1006
     Connect_Get_Service_err = 1007
 
-    Connect_Send_OK  = 2000
+    Connect_Send_OK = 2000
     Connect_Send_Gatt_Err = 2001
     Connect_Send_device_Err = 2002
     Connect_Send_Data_Err = 2003
 
+    Connect_Aiai_Login_OK = 3000
+    Connect_Aiai_Login_ERR = 3001
+
+
 class Connect_Status(Enum):
     Connected_OK = 0
     Disconnect = 1
 
 
+'''
+mesh dev login
+'''
+
+
+def Ble_OneBot_Mesh_Login():
+    Onebot_Mesh_Login_1 = "PoW6p99mRQ3yPOhS1dSqnA=="
+    Onebot_Mesh_Login_2 = "Am49m1E9XXyNxW2/bjHZaQ=="
+    Onebot_Mesh_Login_3 = "cP2qHxIa0nPrxuSildnyKw=="
+
+    BluetoothLEAiqi.Bluetooth_Send(blue_gatt, Onebot_Mesh_Login_1)
+    time.sleep(0.2)
+    BluetoothLEAiqi.Bluetooth_Send(blue_gatt, Onebot_Mesh_Login_2)
+    time.sleep(0.2)
+    BluetoothLEAiqi.Bluetooth_Send(blue_gatt, Onebot_Mesh_Login_3)
+    time.sleep(0.3)
+
+
+'''
+mibot login
+
+'''
+
+
+def Ble_Mibot_Login():
+
+    Onebot_Mibot_Login = "78BByM0pzI4R9kcA5G7ra5+JQLL1MoxMMuDxhakTh4qcC86hZGr1GZEIH2+P7FYY"
+
+    time.sleep(0.3)
+    BluetoothLEAiqi.Bluetooth_Send(blue_gatt, Onebot_Mibot_Login)
+
 
 '''
 蓝牙数据发送 
@@ -52,7 +89,8 @@ class Connect_Status(Enum):
 
 '''
 
-def Bluetooth_Send(gatt,send_buff):
+
+def Bluetooth_Send(gatt, send_buff):
     gatt.Aiqi_Bluetooth_Send(send_buff)
 
 
@@ -62,7 +100,8 @@ true is  scan open
 false is scan false
 '''
 
-def Bluetooth_Scan_Ctrl(watch,enable):
+
+def Bluetooth_Scan_Ctrl(watch, enable):
     watch.Bluetooth_Watch_Enable(enable)
 
 
@@ -72,9 +111,11 @@ def Bluetooth_Scan_Ctrl(watch,enable):
 
 '''
 
+
 def Bluetooth_Disconnect(gatt):
     gatt.Bluetooth_Disconnect()
 
+
 '''
 
 蓝牙发现初始化
@@ -82,16 +123,21 @@ def Bluetooth_Disconnect(gatt):
 返回值 蓝牙watcher 实例
 
 '''
+
+
 def Bluetooth_Watch_Init(watch_handle):
     print(aiqi_blue)
-    global ble_watcher
+    global _aiqi_watcher
 
     watch = Bluetooth_watcher()
 
     watch.Aiqi_ble_wachter_handle += watch_handle
 
+    _aiqi_watcher = watch
+
     return watch
 
+
 '''
 蓝牙初始化
 参数 1 蓝牙连接状态回调
@@ -100,17 +146,15 @@ def Bluetooth_Watch_Init(watch_handle):
 返回值 gatt 实例
 '''
 
+
 def Bluetooth_Init(ble_stats_handle, create_stats_handle, char_ValueChanged_handle):
     print(aiqi_blue)
-    global ble_watcher
+    global _aiqi_gatt
 
     gatt = Bluetooth_gatt_class()
     gatt.Aiqi_Ble_connected_stats_handle += ble_stats_handle
     gatt.Aiqi_Characteristic_ValueChanged_handle += char_ValueChanged_handle
     gatt.Aiqi_Ble_connect_build_stats_handle += create_stats_handle
+
+    _aiqi_gatt = gatt
     return gatt
-
-
-
-
-
